@@ -734,10 +734,11 @@ handle_icon_key (kf_validator *kf,
     return FALSE;
   }
 
+  /* FIXME: in the future, we should make this fatal again */
   if (g_str_has_suffix (value, ".png") ||
       g_str_has_suffix (value, ".xpm") ||
       g_str_has_suffix (value, ".svg")) {
-    print_fatal (kf, "value \"%s\" for key \"%s\" in group \"%s\" is an icon "
+    print_warning (kf, "value \"%s\" for key \"%s\" in group \"%s\" is an icon "
                      "name with an extension, but there should be no extension "
                      "as described in the Icon Theme Specification if the "
                      "value is not an absolute path\n",
@@ -1910,7 +1911,8 @@ validate_line_looks_like_group (kf_validator  *kf,
                      "The validation will continue, with the trailing spaces "
                      "ignored.\n", line);
 
-  *group = g_strndup (chomped + 1, strlen (chomped) - 2);
+  if (group && result)
+    *group = g_strndup (chomped + 1, strlen (chomped) - 2);
 
   g_free (chomped);
 
@@ -1987,6 +1989,7 @@ validate_parse_line (kf_validator *kf)
   if (validate_line_is_comment (kf, line))
     return;
 
+  group = NULL;
   if (validate_line_looks_like_group (kf, line, &group)) {
     if (!kf->current_group &&
         (strcmp (group, GROUP_DESKTOP_ENTRY) &&
@@ -2011,6 +2014,8 @@ validate_parse_line (kf_validator *kf)
     return;
   }
 
+  key = NULL;
+  value = NULL;
   if (validate_line_looks_like_entry (kf, line, &key, &value)) {
     if (kf->current_group) {
       GSList      *keys;
@@ -2024,6 +2029,11 @@ validate_parse_line (kf_validator *kf)
       keys = g_slist_prepend (keys, keyvalue);
       g_hash_table_replace (kf->groups, g_strdup (kf->current_group), keys);
     } else {
+      if (key)
+        g_free (key);
+      if (value)
+        g_free (value);
+
       print_fatal (kf, "file contains entry \"%s\" before the first group, "
                        "but only comments are accepted before the first "
                        "group\n", line);
